California Secretary of State - CalAccess - Campaign Finance

Advanced Search
| Candidates & Elected Officials
Propositions & Ballot Measures
Committees, Parties, Major Donors & Slate Mailers
Daily/Late/ Special Filings
| Campaign Finance: PROPOSITION 015 - POLITICAL REFORM ACT OF 1974: CALIFORNIA FAIR ELECTIONS ACT OF 2008. View Information: General Information Late Independent Expenditures Affecting This Measure
How much money is being raised and spent to pass or defeat California propositions and ballot measures, and what are the sources of the money? Check here to follow the money trail.
Committees formed to support or oppose the ballot measure.
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1321911 | YES ON 15 CALIFORNIA COMMON CAUSE FAIR ELECTIONS COMMITTEE | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1317708 | YES ON PROPOSITION 15 - CALIFORNIANS FOR FAIR ELECTIONS, A COALITION OF NURSES AND GOVERNMENT REFORM ADVOCATES | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1322489 | YES ON PROPOSITION 15 - CALIFORNIA CLEAN MONEY ACTION FUND | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1325411 | STOPPROP15.COM, A COALITION OF TAXPAYERS, GOVERNMENTAL ADVOCATES AND SMALL BUSINESSES | OPPOSE